==> haskell-wl-pprint-extras-3.5.0.5-359-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-98v7nsNp8PJ6oF6k26rfmJ
key:                  wl-pprint-extras-3.5.0.5-98v7nsNp8PJ6oF6k26rfmJ
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  a03df56f1e4946afc74dc3059aa029c1
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-98v7nsNp8PJ6oF6k26rfmJ
depends:
    base-4.15.1.0 containers-0.6.4.1
    semigroupoids-5.3.7-oyf52id00A81763SReSSU text-1.2.5.0
    utf8-string-1.0.2-5jfGmdF6tr2LafWWNuWYmN

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-369-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-8SPcNcxdpa8LE6PpI4zCYW
key:                  wl-pprint-extras-3.5.0.5-8SPcNcxdpa8LE6PpI4zCYW
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  001bcde45ed6a430eece01bc09a1dc20
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-8SPcNcxdpa8LE6PpI4zCYW
depends:
    base-4.15.1.0 containers-0.6.4.1
    semigroupoids-5.3.7-J8YG1rXHNsfFOz0i03HsVi text-1.2.5.0
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
